@@ -381,7 +381,10 @@ class Project():
             self._project_conf = _yaml.load(projectfile)
         except LoadError as e:
             # Raise a more specific error here
-            raise LoadError(LoadErrorReason.MISSING_PROJECT_CONF, str(e))
+            if e.reason == LoadErrorReason.MISSING_FILE:
+                raise LoadError(LoadErrorReason.MISSING_PROJECT_CONF, str(e)) from e
+            else:
+                raise
 
         pre_config_node = _yaml.node_copy(self._default_config_node)
         _yaml.composite(pre_config_node, self._project_conf)
@@ -572,7 +575,10 @@ class Project():
         # any conditionals specified for project option declarations,
         # or conditionally specifying the project name; will be ignored.
         #
+        # Don't forget to also resolve options in the element and source overrides.
         output.options.process_node(config)
+        output.options.process_node(output.element_overrides)
+        output.options.process_node(output.source_overrides)
 
         # Load base variables
         output.base_variables = _yaml.node_get(config, Mapping, 'variables')
