@@ -32,7 +32,6 @@ from ._exceptions import StreamError, ImplError, BstError
 from ._message import Message, MessageType
 from ._scheduler import Scheduler, SchedStatus, TrackQueue, FetchQueue, BuildQueue, PullQueue, PushQueue
 from ._pipeline import Pipeline, PipelineSelection
-from ._platform import Platform
 from . import utils, _yaml, _site
 from . import Scope, Consistency
 
@@ -71,8 +70,7 @@ class Stream():
         #
         # Private members
         #
-        self._platform = Platform.get_platform()
-        self._artifacts = self._platform.artifactcache
+        self._artifacts = context.artifactcache
         self._context = context
         self._project = project
         self._pipeline = Pipeline(context, project, self._artifacts)
@@ -346,6 +344,20 @@ class Stream():
         if not self._artifacts.has_push_remotes():
             raise StreamError("No artifact caches available for pushing artifacts")
 
+        # Mark all dependencies of all selected elements as "pulled" before
+        # trying to push.
+        #
+        # In non-strict mode, elements which are cached by their weak keys
+        # will attempt to pull a remote artifact by it's strict key and prefer
+        # a strict key artifact, however pull does not occur when running
+        # a `bst push` session.
+        #
+        # Marking the elements as pulled is a workaround which ensures that
+        # the cache keys are resolved before pushing.
+        #
+        for element in elements:
+            element._pull_done()
+
         self._pipeline.assert_consistent(elements)
         self._add_queue(PushQueue(self._scheduler))
         self._enqueue_plan(elements)
