@@ -149,8 +149,12 @@ class Plugin():
     # Unique id generator for Plugins
     #
     # Each plugin gets a unique id at creation.
-    # Ids are a monotically increasing integer
-    __id_generator = itertools.count()
+    #
+    # Ids are a monotically increasing integer which
+    # starts as 1 (a falsy plugin ID is considered unset
+    # in various parts of the codebase).
+    #
+    __id_generator = itertools.count(1)
 
     # Hold on to a lookup table by counter of all instantiated plugins.
     # We use this to send the id back from child processes so we can lookup
@@ -163,7 +167,7 @@ class Plugin():
     # scheduling tasks.
     __TABLE = WeakValueDictionary()
 
-    def __init__(self, name, context, project, provenance, type_tag):
+    def __init__(self, name, context, project, provenance, type_tag, unique_id=None):
 
         self.name = name
         """The plugin name
@@ -184,10 +188,14 @@ class Plugin():
         # to give us a topological sort over all elements.
         # Modifying how we handle ids here will modify the behavior of the
         # Element's state handling.
-        self._unique_id = next(self.__id_generator)
-
-        # register ourself in the table containing all existing plugins
-        self.__TABLE[self._unique_id] = self
+        if unique_id is None:
+            # Register ourself in the table containing all existing plugins
+            self._unique_id = next(self.__id_generator)
+            self.__TABLE[self._unique_id] = self
+        else:
+            # If the unique ID is passed in the constructor, then it is a cloned
+            # plugin in a subprocess and should use the same ID.
+            self._unique_id = unique_id
 
         self.__context = context        # The Context object
         self.__project = project        # The Project object
@@ -656,6 +664,7 @@ class Plugin():
     #
     @classmethod
     def _lookup(cls, unique_id):
+        assert unique_id != 0, "Looking up invalid plugin ID 0, ID counter starts at 1"
         assert unique_id in cls.__TABLE, "Could not find plugin with ID {}".format(unique_id)
         return cls.__TABLE[unique_id]
 
